;***************************************************************************
; Some subroutines for timing-management

;------------------------------------------------
;subroutine for event timing
;checks if time (mscnt) has passed contents of a selected timer register
;input: W= timing register address 
;returns STATUS,C:
;C=1 if mscnt >= timing register, W milliseconds since expiration 
;C=0 if time has not yet expired
;leaves FSR0 = selected timer register
check_time
	movwf	FSR0L
	clrf	FSR0H
;like check_time, but (FSR0) = time_reg, rather than W
check_time_fsr0
	moviw	0[FSR0]			;mscnt - tim_reg: >= 0 if t.expired

	bcf	INTCON,GIE

	subwf	mscnt,W		
	movwf	temp			;case time is over: save passed ms	
	moviw	1[FSR0]			
	subwfb	mscnt+1,W

	bsf	INTCON,GIE

	sublw	0x7F			;C = inverse MSB(W)
	movf	temp,W
	return

;------------------------------------------------
;subroutine for event timing
;sets expiration time (FSR0) to WREG milliseconds from current mscnt

set_time_fsr0
	movwi	0[FSR0]

	bcf	INTCON,GIE

	movf	mscnt,W
	addwf	INDF0,F
	movlw	0
	addwfc	mscnt+1,W

	bsf	INTCON,GIE

	movwi	1[FSR0]
	return

;------------------------------------------------
;subroutine for event timing
;adds W milliseconds to expiration time (FSR0) 

add_time_fsr0
	addwf	INDF0,F
	btfss	STATUS,C
	return
	moviw	1[FSR0]
	addlw	1
	movwi	1[FSR0]
	return

;------------------------------------------------
;wait some s
wait10us
	call	wait2us
wait8us
	call	wait2us
wait6us
	call	wait2us
wait4us
	call	wait2us		
wait2us
	call	wait1us
wait1us
	call	$+1
	return
	
